================
etlstat modules
================

extractor module
----------------

Provides methods to process sets of data files in PC-Axis, CSV, positional TXT, XML or XLS format.

testing
-------
Data files are provided in order to allow execute and pass the unit tests in any development environment, including Travis builds.